==> ovirt-hosted-engine-ha-2.1.0.tar.gz: ovirt-hosted-engine-ha-2.1.0/ovirt_hosted_engine_ha/broker/constants.py <==
#
# ovirt-hosted-engine-ha -- ovirt hosted engine high availability
# Copyright (C) 2013 Red Hat, Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#

"""Constants."""

PACKAGE_NAME = 'ovirt-hosted-engine-ha'
PROGRAM_NAME = 'broker'
PACKAGE_VERSION = '2.1.0'
FULL_PROG_NAME = '{0} {1} {2}'.format(
                 PACKAGE_NAME, PROGRAM_NAME, PACKAGE_VERSION)

# See http://www.gnu.org/software/automake/manual/html_node/Scripts.html
LOG_CONF_FILE = '/etc/ovirt-hosted-engine-ha/broker-log.conf'
LOG_FILE = '/var/log/ovirt-hosted-engine-ha/broker.log'
PID_FILE = '/var/run/ovirt-hosted-engine-ha/broker.pid'

NOTIFY_CONF_FILE = '/var/lib/ovirt-hosted-engine-ha/broker.conf'
NOTIFY_CONF_FILE_ARCHIVE_FNAME = 'broker.conf'
NOTIFY_TEMPLATES = '/etc/ovirt-hosted-engine-ha/notifications'

VDSM_USER = 'vdsm'
VDSM_GROUP = 'kvm'

HOSTED_ENGINE_BINARY = '/usr/sbin/hosted-engine'

==> ovirt-hosted-engine-ha-2.1.0.1.tar.gz: ovirt-hosted-engine-ha-2.1.0.1/ovirt_hosted_engine_ha/broker/constants.py <==
#
# ovirt-hosted-engine-ha -- ovirt hosted engine high availability
# Copyright (C) 2013 Red Hat, Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#

"""Constants."""

PACKAGE_NAME = 'ovirt-hosted-engine-ha'
PROGRAM_NAME = 'broker'
PACKAGE_VERSION = '2.1.0.1'
FULL_PROG_NAME = '{0} {1} {2}'.format(
                 PACKAGE_NAME, PROGRAM_NAME, PACKAGE_VERSION)

# See http://www.gnu.org/software/automake/manual/html_node/Scripts.html
LOG_CONF_FILE = '/etc/ovirt-hosted-engine-ha/broker-log.conf'
LOG_FILE = '/var/log/ovirt-hosted-engine-ha/broker.log'
PID_FILE = '/var/run/ovirt-hosted-engine-ha/broker.pid'

NOTIFY_CONF_FILE = '/var/lib/ovirt-hosted-engine-ha/broker.conf'
NOTIFY_CONF_FILE_ARCHIVE_FNAME = 'broker.conf'
NOTIFY_TEMPLATES = '/etc/ovirt-hosted-engine-ha/notifications'

VDSM_USER = 'vdsm'
VDSM_GROUP = 'kvm'

HOSTED_ENGINE_BINARY = '/usr/sbin/hosted-engine'
